.. currentmodule:: abjad.tools.scoretools

move_measure_prolation_to_full_measure_tuplet
=============================================

.. autofunction:: move_measure_prolation_to_full_measure_tuplet
